#!/usr/bin/python
# coding: utf-8
# (c) 2013 Julian Ceballos <@jceb>

import unittest
import random
import conekta
from datetime import datetime, timedelta


class BaseEndpointTestCase(unittest.TestCase):
    random.seed()

    client = conekta

    card_charge_object = {
        "description": "Grad Stogies: Second Class",
        "amount": 20000,
        "currency": "MXN",
        "reference_id": "9893-cohib_s1_wolf_pack",
        "card": "tok_test_visa_4242",
        "details": {
            "name": "Wolverine",
            "email": "logan.thomas@xmen.org",
            "phone": "403-342-0642",
            "line_items": [{
                "name": "Shades",
                "description": "Imported From Mex.",
                "unit_price": 20000,
                "quantity": 1,
                "sku": "cohb_s1",
                "category": "eyewear"
            }]
        }
    }

    cash_charge_object = {
        "currency": "MXN",
        "amount": 20000,
        "description": "Grad Stogies: Second Class",
        "reference_id": "9893-cohib_s1_wolf_pack",
        "cash": {
            "type": "oxxo"
        },
        "details": {
            "name": "Wolverine",
            "email": "logan.thomas@xmen.org",
            "phone": "403-342-0642",
            "line_items": [{
                "name": "Shades",
                "description": "Imported From Mex.",
                "unit_price": 20000,
                "quantity": 1,
                "sku": "cohb_s1",
                "category": "eyewear"
            }]
        }
    }

    bank_charge_object = {
        "currency": "MXN",
        "amount": 20000,
        "description": "Grad Stogies: Second Class",
        "reference_id": "9893-cohib_s1_wolf_pack",
        "bank": {
            "type": "banorte"
        },
        "details": {
            "name": "Wolverine",
            "email": "logan.thomas@xmen.org",
            "phone": "403-342-0642",
            "line_items": [{
                "name": "Shades",
                "description": "Imported From Mex.",
                "unit_price": 20000,
                "quantity": 1,
                "sku": "cohb_s1",
                "category": "eyewear"
            }]
        }
    }

    spei_charge_object = {
        "currency": "MXN",
        "amount": 20000,
        "description": "Grad Stogies: Second Class",
        "reference_id": "9893-cohib_s1_wolf_pack",
        "bank": {
            "type": "spei"
        },
        "details": {
            "name": "Wolverine",
            "email": "logan.thomas@xmen.org",
            "phone": "403-342-0642",
            "line_items": [{
                "name": "Shades",
                "description": "Imported From Mex.",
                "unit_price": 20000,
                "quantity": 1,
                "sku": "cohb_s1",
                "category": "eyewear"
            }]
        }
    }

    plan_object = {
        'id': 'py_test_plan_' + str(random.randint(1, 1000000)),
        'name': 'Python Test Subscription',
        'amount': 10000,
        'currency': 'MXN',
        'interval': 'week',
        'frequency': 3
    }

    customer_object = {
        'name': 'James Howlett',
        'email': 'logan@x-men.org',
        'phone': '+525511223344',
        'payment_sources': [
            {'token_id': 'tok_test_visa_4242',
             'type': 'card'},
            {'token_id': 'tok_test_mastercard_5100',
             'type': 'card'}
        ],
        "shipping_contacts": [{
            "phone": "+525511223344",
            "receiver": "Marvin Fuller",
            "between_streets": "Ackerman Crescent",
            "address": {
                "street1": "250 Alexis St",
                "city": "Red Deer",
                "state": "Alberta",
                "country": "CA",
                "postal_code": "T4N 0B8"
            }

        }]
    }

    payee_object = {
        'name': 'Graydon Creed',
        'email': 'graydon@friendsofhumanity.com',
        'phone': '5555555555',
        'bank': {
            'account_number': '123456789012345673',
            'account_holder': 'Friends of Humanity'
        }
    }

    payout_method_object = {
        'type': 'bank_transfer_payout_method',
        'account_number': '123456789012345673',
        'account_holder': 'Friends of Humanity'
    }

    order_object = {
        "line_items": [
            {
                "name": "Box of Cohiba S1s",
                "description": "Imported From Mex.",
                "unit_price": 20000,
                "quantity": 1,
                "sku": "cohb_s1",
                "category": "food",
                "type": "physical",
                "tags": ["food", "mexican food"]
            }
        ],
        "tax_lines": [
            {
                "description": "IVA",
                "amount": 600,
                "metadata": {
                    "random_key": "random_value"
                }
            }],
        "shipping_lines": [
            {
                "amount": 0,
                "tracking_number": "TRACK123",
                "carrier": "USPS",
                "method": "Train",
                "metadata": {
                    "random_key": "random_value"
                }
            }],
        "discount_lines": [
            {
                "code": "descuento",
                "type": "loyalty",
                "amount": 600
            }],
        "customer_info": {
            "name": "John Constantine",
            "phone": "+525533445566",
            "email": "john@meh.com",
            "corporate": False,
            "vertical_info": {}
        },
        "shipping_contact": {
            "phone": "5544332211",
            "receiver": "Marvin Fuller",
            "between_streets": "Ackerman Crescent",
            "address": {
                "street1": "250 Alexis St",
                "state": "Alberta",
                "country": "MX",
                "postal_code": "23455",
                "metadata": {"soft_validations": True}
            }
        },
        "charges": [{
            "payment_method": {
                "type": "oxxo_cash"
            },
            "amount": 20000
        }],
        "currency": "mxn",
        "metadata": {"test": "extra info"}
    }
    line_item_object = {
        "name": "test line item",
        "description": "Imported From Mex.",
        "unit_price": 10000,
        "quantity": 2,
        "sku": "noSKU",
        "category": "food",
        "type": "physical",
        "tags": ["food", "mexican food"]
    }
    tax_line_object = {
        "description": "IVA2",
        "amount": 600,
        "metadata": {
            "random_key": "random_value"
        }
    }

    shipping_lines_object = {
        "amount": 0,
        "tracking_number": "TRACK123",
        "carrier": "USPS",
        "method": "Train",
        "metadata": {
            "random_key": "random_value"
        }
    }

    discount_line_object = {
        "code": "descuento",
        "type": "loyalty",
        "amount": 100
    }

    order_shipping_contact_object = {
        "shipping_contact": {
            "phone": "+525511223399",
            "receiver": "Marvin Fuller",
            "between_streets": "Ackerman Crescent",
            "address": {
                "street1": "250 Alexis St",
                "state": "Alberta",
                "country": "MX",
                "postal_code": "23455",
                "metadata": {"soft_validations": True}
            }
        }
    }

    charge_object = {
        "payment_method": {
            "type": "oxxo_cash"
        },
        "amount": 20000
    }

    payment_source_object = {
        'token_id': 'tok_test_visa_4242',
        'type': 'card'
    }

    update_payment_source_object = {
        "name": "Emiliano Cabrera",
        "exp_month": "12",
        "exp_year": "29",
        "address": {
            "street1": "Nuevo leon",
            "city": "Monterrey",
            "state": "Nuevo Leon",
            "country": "MX",
            "postal_code": "64700"
        }
    }

    shipping_contact_object = {
        "phone": "+525511008811",
        "receiver": "Dr. Manhatan",
        "between_streets": "some streets",
        "address": {
            "street1": "250 Alexis St",
            "city": "Red Deer",
            "state": "Alberta",
            "country": "CA",
            "postal_code": "T4N 0B8"
        }
    }

    checkout_object = {
        "name": "Payment Link Name",
        "type": "PaymentLink",
        "recurrent": False,
        "expired_at": int((datetime.today() + timedelta(days=1)).strftime('%s')),
        "allowed_payment_methods": ["cash", "card", "bank_transfer"],
        "needs_shipping_contact": True,
        "monthly_installments_enabled": False,
        "monthly_installments_options": [3, 6, 9, 12],
        "order_template": {
            "line_items": [{
                "name": "Red Wine",
                "unit_price": 1000,
                "quantity": 10
            }],
            "currency": "MXN",
            "customer_info": {
                "name": "Juan Perez",
                "email": "test@conekta.com",
                "phone": "5566982090"
            }
        }
    }

    checkout_object_multiple = {
        "payments_limit_count": 2,
        "name": "Payment Link Name",
        "type": "PaymentLink",
        "recurrent": True,
        "expired_at": int((datetime.today() + timedelta(days=1)).strftime('%s')),
        "allowed_payment_methods": ["cash", "card", "bank_transfer"],
        "needs_shipping_contact": True,
        "monthly_installments_enabled": False,
        "monthly_installments_options": [3, 6, 9, 12],
        "order_template": {
            "line_items": [{
                "name": "Red Wine",
                "unit_price": 1000,
                "quantity": 10
            }],
            "currency": "MXN",
            "customer_info": {
                "name": "Juan Perez",
                "email": "test@conekta.com",
                "phone": "5566982090"
            }
        }
    }

    checkout_object_msi = {
        "payments_limit_count" : 2,
        "name": "Payment Link Name",
        "type": "PaymentLink",
        "recurrent": True,
        "expired_at": int((datetime.today() + timedelta(days=1)).strftime('%s')),
        "allowed_payment_methods": ["cash", "card", "bank_transfer"],
        "needs_shipping_contact": True,
        "monthly_installments_enabled": True,
        "monthly_installments_options": [3, 6, 9, 12],
        "order_template": {
            "line_items": [{
                "name": "Red Wine",
                "unit_price": 1000,
                "quantity": 10
            }],
            "currency": "MXN",
            "customer_info": {
                "name": "Juan Perez",
                "email": "test@conekta.com",
                "phone": "5566982090"
            }
        }
    }

    checkout_object_type_checkout = {
        "name": "Payment Link Name",
        "type": "checkout",
        "recurrent": True,
        "expired_at": 1590882634,
        "allowed_payment_methods": ["cash", "card", "bank_transfer"],
        "needs_shipping_contact": True,
        "monthly_installments_enabled": True,
        "monthly_installments_options": [3, 6, 9, 12],
        "order_template": {
            "line_items": [{
                "name": "Red Wine",
                "unit_price": 1000,
                "quantity": 10
            }],
            "currency": "MXN",
            "customer_info": {
                "name": "Juan Perez",
                "email": "test@conekta.com",
                "phone": "5566982090"
            }
        }
    }

    checkout_object_send = {
        "id": "05b25724-df59-4925-8762-105d627875fd",
        "name": "Payment Link Name",
        "type": "checkout",
        "recurrent": True,
        "expired_at": 1590882634,
        "allowed_payment_methods": ["cash", "card", "bank_transfer"],
        "needs_shipping_contact": True,
        "monthly_installments_enabled": True,
        "monthly_installments_options": [3, 6, 9, 12],
        "order_template": {
            "line_items": [{
                "name": "Red Wine",
                "unit_price": 1000,
                "quantity": 10
            }],
            "currency": "MXN",
            "customer_info": {
                "name": "Juan Perez",
                "email": "test@conekta.com",
                "phone": "5566982090"
            }
        }
    }

    checkout_order_object = {
        "currency": "MXN",
        "customer_info": {
            "customer_id": "cus_2tgwCPgJZR56HvkKK"
        },
        "line_items": [{
            "name": "Box of Cohiba S1s",
            "unit_price": 300000,
            "quantity": 1
        }],
        "shipping_lines": [{
            "amount": 0
        }],
        "checkout": {
            "allowed_payment_methods": ["cash", "card", "bank_transfer"],
            "multifactor_authentication": False,
            "monthly_installments_enabled": False,
            "monthly_installments_options": [3, 6, 9, 12, 18],
            "expired_at": int((datetime.today() + timedelta(days=1)).strftime('%s'))
        },
        "shipping_contact": {
            "phone": "+5215555555555",
            "receiver": "Marvin Fuller",
            "address": {
                "street1": "Nuevo Leon 4",
                "country": "MX",
                "postal_code": "06100"
            }
        }}

    checkout_msi_order__object = {
        "currency": "MXN",
        "customer_info": {
            "customer_id": "cus_2tgwCPgJZR56HvkKK"
        },
        "line_items": [{
            "name": "Box of Cohiba S1s",
            "unit_price": 300000,
            "quantity": 1
        }],
        "shipping_lines": [{
            "amount": 0
        }],
        "checkout": {
            "type": "Integration",
            "allowed_payment_methods": ["cash", "card", "bank_transfer"],
            "multifactor_authentication": False,
            "monthly_installments_enabled": True,
            "monthly_installments_options": [3, 6, 9, 12, 18],
            "expires_at": 1609891200
        },
        "shipping_contact": {
            "phone": "+5215555555555",
            "receiver": "Marvin Fuller",
            "address": {
                "street1": "Nuevo Leon 4",
                "country": "MX",
                "postal_code": "06100"
            }
        }
    }

    checkout_order__redirect_object = {
        "currency": "MXN",
        "customer_info": {
            "customer_id": "cus_2tgwCPgJZR56HvkKK"
        },
        "line_items": [{
            "name": "Box of Cohiba S1s",
            "unit_price": 300000,
            "quantity": 1
        }],
        "shipping_lines": [{
            "amount": 0
        }],
        "checkout": {
            "type": "HostedPayment",
            "success_url": "https://testredirect.com",
            "failure_url": "https://testredirect.com",
            "allowed_payment_methods": ["cash", "card", "bank_transfer"],
            "multifactor_authentication": False,
            "monthly_installments_enabled": False,
            "monthly_installments_options": [3, 6, 9, 12, 18],
            "expired_at": int((datetime.today() + timedelta(days=1)).strftime('%s'))
        },
        "shipping_contact": {
            "phone": "+5215555555555",
            "receiver": "Marvin Fuller",
            "address": {
                "street1": "Nuevo Leon 4",
                "country": "MX",
                "postal_code": "06100"
            }
        }
    }



#!/usr/bin/python
# coding: utf-8
# (c) 2013 Julian Ceballos <@jceb>
# (c) 2014- Leo Fischer / Conekta <@leofischer/@conektaio>

from . import BaseEndpointTestCase


class LogsEndpointTestCase(BaseEndpointTestCase):

    def test_01_log_complete(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        logs = self.client.Log.where({})
        self.assertIsInstance(logs.data[0], self.client.Log)
        retrieved_log = self.client.Log.find(logs.data[0].id)
        assert retrieved_log.id



#!/usr/bin/python
# coding: utf-8
# (c) 2013 Julian Ceballos <@jceb>
# (c) 2014- Leo Fischer / Conekta <@leofischer/@conektaio>

from . import BaseEndpointTestCase


class EventsEndpointTestCase(BaseEndpointTestCase):

    def test_01_order_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order = self.client.Order.create(self.order_object.copy())
        event = order.events()

        assert event.data

    def test_02_line_item_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)

        line_item = order.line_items[0]
        line_item.update(self.line_item_object.copy())

        event = order.line_items[0].events()

        assert event.total
        assert event.object

    def test_03_tax_line_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)

        tax_line = order.tax_lines[0]
        tax_line.update(self.tax_line_object.copy())

        event = order.tax_lines[0].events()

        assert event.total
        assert event.object

    def test_04_shipping_lines_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)

        shipping_line = order.shipping_lines[0]
        shipping_line.update(self.shipping_lines_object.copy())

        event = order.shipping_lines[0].events()

        assert event.total
        assert event.object

    def test_05_discount_lines_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)

        discount_line = order.discount_lines[0]
        discount_line.update(self.discount_line_object.copy())

        event = order.discount_lines[0].events()

        assert event.total
        assert event.object

    def test_06_discount_lines_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)

        discount_line = order.discount_lines[0]
        discount_line.update(self.discount_line_object.copy())

        event = order.discount_lines[0].events()

        assert event.total
        assert event.object

    def test_07_customer_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        customer = self.client.Customer.create(self.customer_object.copy())

        event = customer.events()

        assert event.data

    def test_08_customer_payment_source_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        customer = self.client.Customer.create(self.customer_object.copy())
        payment_source = customer.payment_sources[0]
        payment_source.update(self.update_payment_source_object.copy())
        event = customer.payment_sources[0].events()

        assert event.total
        assert event.object

    def test_09_customer_shipping_contact_event(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        customer = self.client.Customer.create(self.customer_object.copy())
        shipping_contact = customer.shipping_contacts[0]
        shipping_contact.update(self.shipping_contact_object.copy())
        event = customer.shipping_contacts[0].events()

        assert event.total
        assert event.object



#!/usr/bin/python
# coding: utf-8
# (c) 2017 Ramses Carbajal <@RamsesCarbajal>

from . import BaseEndpointTestCase
from nose.tools import assert_raises


class OrdersEndpointTestCase(BaseEndpointTestCase):

    def test_01_order_create(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order = self.client.Order.create(self.order_object.copy())
        assert order.currency
        line_item = order.line_items[0]
        assert line_item.name == "Box of Cohiba S1s"
        tax_line = order.tax_lines[0]
        assert tax_line.description == "IVA"
        shipping_line = order.shipping_lines[0]
        assert shipping_line.tracking_number == "TRACK123"
        discount_lines = order.discount_lines[0]
        assert discount_lines.code == "descuento"
        assert order.customer_info.name == "John Constantine"
        assert order.shipping_contact.receiver == "Marvin Fuller"
        charge = order.charges[0]
        assert charge.payment_method.service_name == "OxxoPay"
        assert charge.amount == 20000

    def test_02_order_create_line_item(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)
        line_item = order.createLineItem(self.line_item_object.copy())
        assert line_item.name == "test line item"
        assert line_item.unit_price == 10000

    def test_03_order_create_tax_item(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)
        tax_line = order.createTaxLine(self.tax_line_object.copy())
        assert tax_line.description == "IVA2"
        assert tax_line.amount == 600

    def test_04_order_create_shipping_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)
        shipping_line = order.createShippingLine(self.shipping_lines_object.copy())
        assert shipping_line.tracking_number == "TRACK123"

    def test_05_order_create_discount_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        order = self.client.Order.create(raw_order)
        discount_line = order.createDiscountLine(self.discount_line_object.copy())
        assert discount_line.code == "descuento"
        assert discount_line.amount == 100

    def test_06_order_create_shipping_contact(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        raw_order["charges"] = None
        del raw_order["shipping_contact"]
        order = self.client.Order.create(raw_order)
        shipping_contact = order.createShippingContact(self.order_shipping_contact_object.copy())
        assert shipping_contact.phone == "+525511223399"

    def test_07_order_create_charge(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        charge = order.charge(self.charge_object)
        assert charge.object == "charge"
        assert charge.status == "pending_payment"

    def test_08_order_update_line_item(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        line_item = order.line_items[0]
        raw_line_item = self.line_item_object.copy()
        del raw_line_item["tags"]
        del raw_line_item["type"]
        raw_line_item["unit_price"] = 30000
        raw_line_item["description"] = "some description"
        line_item.update(raw_line_item)
        line_item = order.line_items[0]
        assert line_item.unit_price == 30000
        assert line_item.description == "some description"

    def test_09_order_get_all_line_items(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'

        large_order_by_find = self.client.Order.find('ord_2ti8wMTYM7UnpS8Gd')
        large_order_by_where = self.client.Order.where({'search': 'ord_2ti8wMTYM7UnpS8Gd'})

        assert len(large_order_by_where.data[0].line_items) == 1
        assert len(large_order_by_find.line_items) == 1

    def test_10_order_update_tax_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        tax_line = order.tax_lines[0]
        raw_tax_line = self.tax_line_object.copy()
        raw_tax_line["description"] = "newIva"
        raw_tax_line["amount"] = 321
        tax_line.update(raw_tax_line)
        valid_tax_line = order.tax_lines[0]
        assert valid_tax_line.description == "newIva"
        assert valid_tax_line.amount == 321

    def test_11_order_update_shipping_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        shipping_line = order.shipping_lines[0]
        raw_shipping_line = self.shipping_lines_object.copy()
        raw_shipping_line["tracking_number"] = "fake track number"
        raw_shipping_line["amount"] = 321
        shipping_line.update(raw_shipping_line)
        shipping_line = order.shipping_lines[0]
        assert shipping_line.tracking_number == "fake track number"

    def test_12_order_update_discount_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        discount_line = order.discount_lines[0]
        raw_discount_line = self.discount_line_object.copy()
        raw_discount_line["code"] = "promocion"
        discount_line.update(raw_discount_line)
        discount_line = order.discount_lines[0]
        assert discount_line.code == "promocion"

    def test_13_order_with_token_id(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        charge = {"payment_method": {}}
        charge["payment_method"]["type"] = "card"
        charge["payment_method"]["token_id"] = "tok_test_visa_4242"
        raw_order["charges"] = [charge]

        order = self.client.Order.create(raw_order)
        charge = order.charges[0]
        assert charge.status == "paid"
        assert charge.amount == 20000

    def test_14_order_capture(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        charge = {"payment_method": {}}
        charge["payment_method"]["type"] = "card"
        charge["payment_method"]["token_id"] = "tok_test_visa_4242"
        raw_order["charges"] = [charge]
        raw_order["pre_authorize"] = True
        order = self.client.Order.create(raw_order)

        assert order.charges[0].amount == 20000
        assert order.charges[0].status == "pre_authorized"
        assert order.payment_status == "pre_authorized"

        capture_param = {}
        order.capture(capture_param)
        charge = order.charges[0]

        assert charge.amount == 20000
        assert charge.status == "paid"
        assert order.payment_status == "paid"

    def test_15_order_refund(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        charge = {}
        charge["payment_method"] = {}
        charge["payment_method"]["type"] = "card"
        charge["payment_method"]["token_id"] = "tok_test_visa_4242"
        raw_order["charges"] = [charge]

        order = self.client.Order.create(raw_order)
        order_refund_params = {}

        order_refund_params["reason"] = "requested_by_client"
        order_refund_params["amount"] = 20000

        refunded_order = order.refund(order_refund_params)

        assert refunded_order.payment_status == "refunded"

    def test_15_order_void(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        charge = {"payment_method": {}}
        charge["payment_method"]["type"] = "card"
        charge["payment_method"]["token_id"] = "tok_test_visa_4242"
        raw_order["charges"] = [charge]
        raw_order["pre_authorize"] = True
        order = self.client.Order.create(raw_order)

        assert order.charges[0].amount == 20000
        assert order.charges[0].status == "pre_authorized"
        assert order.payment_status == "pre_authorized"

        refunded_order = order.void()

        assert refunded_order.payment_status == "voided"

    def test_16_order_delete_line_item(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        order.createLineItem(self.line_item_object.copy())
        line_item = order.line_items[0]
        line_item_deleted = line_item.delete()

        assert line_item_deleted.deleted == True

        line_item = order.line_items[0]
        assert line_item.unit_price == 10000
        assert line_item.description == "Imported From Mex."

    def test_17_order_delete_tax_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        order.createTaxLine(self.tax_line_object.copy())
        tax_line = order.tax_lines[0]
        tax_line_deleted = tax_line.delete()

        assert tax_line_deleted.deleted == True

        tax_line = order.tax_lines[0]
        assert tax_line.description == "IVA2"
        assert tax_line.amount == 600

    def test_18_order_delete_shipping_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        order.createShippingLine(self.shipping_lines_object.copy())
        shipping_line = order.shipping_lines[0]
        shipping_line_deleted = shipping_line.delete()

        assert shipping_line_deleted.deleted == True

        shipping_line = order.shipping_lines[0]
        assert shipping_line.tracking_number == "TRACK123"
        assert shipping_line.amount == 0

    def test_18_order_delete_discount_line(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        raw_order = self.order_object.copy()
        del raw_order["charges"]
        order = self.client.Order.create(raw_order)
        order.createDiscountLine(self.discount_line_object.copy())
        discount_line = order.discount_lines[0]
        discount_line_deleted = discount_line.delete()

        assert discount_line_deleted.deleted == True

        discount_line = order.discount_lines[0]
        assert discount_line.code == "descuento"
        assert discount_line.type == "loyalty"

    def test_19_order_create_with_customer_id(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        customer = self.client.Customer.create(self.customer_object.copy())
        order_params = self.order_object.copy()
        del order_params["customer_info"]
        order_params["customer_info"] = {}
        order_params["customer_info"]["customer_id"] = customer.id

        charge_params = {}
        charge_params["payment_method"] = {}
        charge_params["payment_method"]["type"] = "card"
        charge_params["payment_method"]["token_id"] = "tok_test_visa_4242"
        order_params["charges"] = [charge_params]

        del order_params["shipping_contact"]
        order = self.client.Order.create(order_params)

        charge = order.charges[0]

        assert charge.status == "paid"
        assert charge.amount == 20000

    def test_20_order_create_fails(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order_params = self.order_object.copy()
        del order_params['line_items']
        with assert_raises(self.client.ConektaError) as ex:
            self.client.Order.create(order_params)

        assert ex.exception.args[0]['details'][0]['code'] == "conekta.errors.parameter_validation.line_items.missing"
        assert ex.exception.error_json['details'][0]['code'] == "conekta.errors.parameter_validation.line_items.missing"
        assert ex.exception.code == "conekta.errors.parameter_validation.line_items.missing"



#!/usr/bin/python
#coding: utf-8
#(c) 2013 Julian Ceballos <@jceb>

from setuptools import setup, find_packages

version = "2.6.3"
author = "Conekta"

setup(
    name='conekta',
    version=version,
    author=author,
    author_email='soporte@conekta.io',
    url='https://github.com/conekta/conekta-python',
    description='Easy Conekta python wrapper',
    long_description=open('./README.txt', 'r').read(),
    download_url='https://github.com/conekta/conekta-python/tarball/master',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'License :: OSI Approved :: MIT License',
        ],
    packages=find_packages(),
    install_requires=[
        'simplejson',
        'nose',
        'requests'
    ],
    license='MIT License',
    keywords='conekta wrapper',
    include_package_data=True,
    zip_safe=True,
)



#!/usr/bin/python
# coding: utf-8
# (c) 2020 Erick Colin <@erickcolin>

from . import BaseEndpointTestCase


class CheckoutsEndpointTestCase(BaseEndpointTestCase):

    def test_01_create_checkout(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object.copy())

        assert checkout.type == "PaymentLink"
        assert checkout.object == "checkout"
        assert checkout.status == "Issued"
        assert checkout.url.startswith("https://pay.conekta")
        assert len(checkout.id) == 36

    def test_02_create_checkout_recurrent(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object_multiple.copy())

        assert checkout.recurrent == True
        assert checkout.type == "PaymentLink"
        assert checkout.object == "checkout"
        assert checkout.url.startswith("https://pay.conekta")
        assert len(checkout.id) == 36

    def test_03_create_checkout_msi(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object_msi.copy())

        assert checkout.monthly_installments_enabled == True
        assert checkout.type == "PaymentLink"
        assert checkout.object == "checkout"
        assert checkout.url.startswith("https://pay.conekta")
        assert len(checkout.id) == 36

    def test_04_checkout_sendmail(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object.copy())
        response = checkout.sendEmail(self.checkout_object_send.copy())

        assert response.emails_sent == 1

    def test_05_checkout_sendsms(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object.copy())
        response = checkout.sendSms(self.checkout_object_send.copy())

        assert response.sms_sent == 1

    def test_06_checkout_cancel(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        checkout = self.client.Checkout.create(self.checkout_object.copy())
        canceled_checkout = checkout.cancel(self.checkout_object_send.copy())

        assert canceled_checkout.status == "Cancelled"

    def test_07_orders_checkout_create(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order = self.client.Order.create(self.checkout_order_object.copy())

        checkout = order.checkout
        assert checkout.type == "Integration"
        assert checkout.status == "Issued"
        assert len(checkout.id) == 36

    def test_08_orders_checkout_create_redirection(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order = self.client.Order.create(self.checkout_order__redirect_object.copy())

        checkout = order.checkout
        assert checkout.type == "HostedPayment"
        assert checkout.status == "Issued"
        assert checkout.url.startswith("https://pay.conekta")
        assert len(checkout.id) == 36

    def test_09_orders_checkout__msi_create(self):
        self.client.api_key = 'key_ZLy4aP2szht1HqzkCezDEA'
        order = self.client.Order.create(self.checkout_order_object.copy())

        checkout = order.checkout
        self.assertFalse(checkout.monthly_installments_enabled)
        assert checkout.type == "Integration"
        assert checkout.status == "Issued"
        assert len(checkout.id) == 36
